==> kaspaliste-0.91.tar.bz2: kaspaliste-0.91/kaspaliste/kliste/author.cpp <==
/***************************************************************************
                          author.cpp  -  description
                             -------------------
    begin                : Tue Sep 7 1999
    copyright            : (C) 1999 by Jan Mueller
    email                : janmueller7@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "author.h"
#include "kaspawidget.h"
#include "resource.h"
#include <kapp.h>
#include <qstring.h>
#include <qmessagebox.h>
#include <kiconloader.h>
#include <klocale.h>
#include "notetreedlg.h"
#include "selectiondlg.h"
#include <qwhatsthis.h>
#include <qwidget.h>
#include <kapp.h>
#include <ktoolbar.h>
#include <kmdcodec.h>


#define Inherited AuthorData


CommandSetup authorcs[] = {	{ID_AUTHOR_DELREC,  RW},
														{ID_AUTHOR_NEWLINK, RW+RO},
														{ID_AUTHOR_INSLINK, RW+RO},
														{ID_AUTHOR_REMLINK, RW+RO},
														{ID_AUTHOR_NEWPUBL, RW+RO},
														{ID_AUTHOR_INSPUBL, RW+RO},
														{ID_AUTHOR_REMPUBL, RW+RO},
														{ID_AUTHOR_FLUSH, 	RW},
														{ID_AUTHOR_INSPART, RW+RO},
														{ID_AUTHOR_REMPART, RW+RO},
														{ID_AUTHOR_RESET,		RW+RO+INV} };



// AuthorBase-Constructor reads row matching WHERE-Clause.
Author::Author(KaspaURL url, Sql *conn, QWidget* parent,	const char* name=0L):
  Inherited( parent, name) {
    setTabOrder(firstname, lastname);
		setTabOrder(lastname, pseudonym);
		setTabOrder(pseudonym, born);
		setTabOrder(born, died);
		setTabOrder(died, country);
		setTabOrder(country, memo);

	QWhatsThis::add(firstname,	i18n("The first name of an author."));
	QWhatsThis::add(lastname, 	i18n("The name of an author."));	
	QWhatsThis::add(pseudonym,	i18n("Your author might have a pseudonym."));		
	QWhatsThis::add(born,				i18n("Once upon a time your author might have been born..."));		
	QWhatsThis::add(died,				i18n("The date of the death of an author."));		
	QWhatsThis::add(country,		i18n("The country where your author is from."));		
	QWhatsThis::add(memo , 			i18n("This textarea takes your annotations about the author."));
	QWhatsThis::add(notelist,		i18n("This box shows the links to the notes connected to an author. " \
																	 "You may open the link by double-clicking the item in the same window " \
																	 "or via the context menu in an new window. You can open the context menu" \
																	 "by clicking the right mouse button. You may insert, create and delete " \
																	 "notes with the buttons of the toolbar."));
	QWhatsThis::add(partlist,		i18n("Your author might have written some articles in a collection or a journal. " \
																	 "This box shows these parts." \
																	 "You may open a part in the same by double-clicking the item " \
																	 "or in a new window via the context menu. You can open the context menu " \
																	 "by clicking the right mouse button. You may insert and delete " \
																	 "parts with the buttons of the toolbar."));
	QWhatsThis::add(publlist,		i18n("This box shows the publications written by an author. " \
																	 "You may open a publication in the same window by double-clicking the item " \
																	 "or in a new window via the context menu. You can open the context menu " \
																	 "by clicking the right mouse button. You may insert, create and delete " \
																	 "publications with the buttons of the toolbar."));
		
	if(url.command()=="new")
	  author = new AuthorBase(conn);
	else
 		author = new AuthorBase(url.where(), conn);

  ASSERT(author);
	author->setCallBack(&idle);
	QString s("kaspa://author#where author.no="); s+=QString().setNum(author->id());
	_url=s;

  connect(notelist, SIGNAL(open(Oid, bool)), this, SLOT(requestNote(Oid, bool)));
  connect(publlist, SIGNAL(open(Oid, bool)), this, SLOT(requestPublication(Oid, bool)));
  connect(partlist, SIGNAL(open(Oid, bool)), this, SLOT(requestPart(Oid, bool)));
	notelist->setTitle(i18n("Links"));
	publlist->setTitle(i18n("Publications"));
	partlist->setTitle(i18n("Chapters"));
}

Author::~Author() {
  debug("Author::~Author");
  delete author;
}

bool Author::isValid() {
	try {
	  return author->isValid();
	} catch(KaspaErr &err) {
		handleWarning(err);
		return false;
	}
}

void Author::reread() {
  debug("Author::reread()");
  setWorkingGUI();
	try {
	  author->reset();
	} catch(KaspaErr &err) {
		handleWarning(err);
	}
  setFields();
}

void Author::setFields() {
  if(isValid()) {
		try {
			setWorkingGUI();
  		firstname->setText(author->getFirstName());
	  	lastname->setText(author->getLastName());
	  	born->setText(author->getBirthday());
		  died->setText(author->getDay_of_Death());
  		pseudonym->setText(author->getPseudonym());
		  country->setText(author->getCountry());
  		memo->setText(QCString(author->getMemo()));
			created->setText(QString("created: ")+author->getCreated());
			modified->setText(QString("modified: ")+author->getModified());

		  notelist->set(author->getLinks());
		  publlist->set(author->getPubl());
		  partlist->set(author->getParts());
		} catch(KaspaErr &err) {
			handleWarning(err);
		}
	}
  setupGUI();
}

void Author::flush() {
	setWorkingGUI();
	save();
	setupGUI();
}

void Author::save(bool block) {
  debug("Author::save()");
	try {
	  if(isValid() && !isReadOnly() && !isWorking()) {
	    if(strcmp(firstname->text(), author->getFirstName()))
	      author->setFirstName(firstname->text());
	    if(strcmp(lastname->text(), author->getLastName()))
	      author->setLastName(lastname->text());
	    if(strcmp(born->text(), author->getBirthday()))
	      author->setBirthday(born->text());
	    if(strcmp(died->text(), author->getDay_of_Death()))
	      author->setDay_of_Death(died->text());
	    if(strcmp(pseudonym->text(), author->getPseudonym()))
	      author->setPseudonym(pseudonym->text());
	    if(strcmp(country->text(), author->getCountry()))
	      author->setCountry(country->text());
	    if(strcmp(QCString(memo->text()), author->getMemo()))
	      author->setMemo(QCString(memo->text()));
		    author->flush(block);
		}
	} catch(KaspaErr &err) {
		handleWarning(err);
	}
}

void Author::setInvalidGUI() {
  debug("Author::setInvalidGUI()");
  Inherited::setInvalidGUI();
  lockGUI();
	for(unsigned int i=0; i<sizeof(authorcs)/sizeof(CommandSetup); i++)
		emit enableCommand(authorcs[i].command, ((authorcs[i].setup&INV)==INV));
}	

void Author::setReadWriteGUI() {
  debug("Author::setReadWriteGUI()");
  Inherited::setReadWriteGUI();
  unlockGUI();
	for(unsigned int i=0; i<sizeof(authorcs)/sizeof(CommandSetup); i++)
		emit enableCommand(authorcs[i].command, ((authorcs[i].setup&RW)==RW));
}

void Author::setReadOnlyGUI() {
  debug("Author::setReadOnlyGUI()");	
  Inherited::setReadOnlyGUI();
  lockGUI();
  notelist->setEnabled(true);
  publlist->setEnabled(true);
	partlist->setEnabled(true);
	for(unsigned int i=0; i<sizeof(authorcs)/sizeof(CommandSetup); i++)
		emit enableCommand(authorcs[i].command, ((authorcs[i].setup&RO)==RO));
}

void Author::setWorkingGUI() {
  debug("Author::setWorkingGUI()");
	if(isReadOnly() || !isValid())
		lockGUI();
	else
		unlockGUI();
  Inherited::setWorkingGUI();
  notelist->setEnabled(false);
  publlist->setEnabled(false);
	partlist->setEnabled(false);
	for(unsigned int i=0; i<sizeof(authorcs)/sizeof(CommandSetup); i++)
		emit enableCommand(authorcs[i].command, ((authorcs[i].setup&WORK)==WORK));
}


void Author::del() {
	try  {
	  if(isValid() && !isReadOnly() && !isWorking() && deleteDlg()) {
	    setWorkingGUI();
	    author->deleteRec();
	    setInvalidGUI();
		}
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}

bool Author::closeRequest() {
  save(true);
	setupGUI();
  return true;
}


void Author::newLink() {
	try {
		Oid o=author->createNote();
		requestNote(o);
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}

void Author::insLink() {
	try {
		NoteTitle *notes=author->getNotes();
		PublTitle *publs=author->getPubls();
		NoteTreeDlg dlg(notes, publs);
		if(dlg.exec()) {
			if(dlg.getOid()==InvalidOid) return;
			setWorkingGUI();
			author->insertLink(dlg.getOid());
			save();
			setFields();	
		}
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}

/*
	try {
		SelectionDlg dlg(author->getNotes(), this);
		if(dlg.exec()) {
			Oid o=dlg.getOid();
			if(o==InvalidOid) return;
			setWorkingGUI();
			author->insertLink(o);
			save();
			setFields();
		}
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}
*/

void Author::remLink() {
	try {
		Oid o=notelist->getCurrentOid();
		if(o==InvalidOid) return;
		setWorkingGUI();
		author->removeLink(o);
		save();
		setFields();
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}
		
void Author::newPubl() {
	try {
		Oid o=author->createPubl();
		requestPublication(o);
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}
	
void Author::insPubl() {
	try {
		SelectionDlg dlg(author->getPubls(), this);
		if(dlg.exec()) {
			Oid o=dlg.getOid();
			if(o==InvalidOid) return;
			setWorkingGUI();
			author->insertPubl(o);
			save();
			setFields();			
		}
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}		
	
void Author::remPubl() {
	try {
		Oid o=publlist->getCurrentOid();
		if(o==InvalidOid) return;
		setWorkingGUI();
		author->removePubl(o);
		save();
		setFields();	
		} catch(KaspaErr& err) {
			handleWarning(err);
		}
}
		
void Author::insPart() {
	try {
		SelectionDlg dlg(author->getParts(), this);
		if(dlg.exec()) {
			Oid o=dlg.getOid();
			if(o==InvalidOid) return;
			setWorkingGUI();
			author->insertPart(o);
			save();
			setFields();	
		}
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}		
	
void Author::remPart() {
	try {
	Oid o=partlist->getCurrentOid();
	if(o==InvalidOid) return;
		setWorkingGUI();
		author->removePart(o);
		save();
		setFields();	
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}

KToolBar *Author::getToolBar() {
	KaspaToolBar *toolbar = new KaspaToolBar(topLevelWidget());
  toolbar->insertButton(BarIcon("newnote.png"), ID_AUTHOR_NEWLINK, SIGNAL(clicked()),
				this, SLOT(newLink()), true, i18n("New Note") );
  toolbar->insertButton(BarIcon("insnote.png"), ID_AUTHOR_INSLINK, SIGNAL(clicked()),
				this, SLOT(insLink()), true, i18n("Insert Note") );
  toolbar->insertButton(BarIcon("delnote.png"), ID_AUTHOR_REMLINK, SIGNAL(clicked()),
				this, SLOT(remLink()), true, i18n("Delete Note") );
	toolbar->insertLineSeparator();
  toolbar->insertButton(BarIcon("newpubl.png"), ID_AUTHOR_NEWPUBL, SIGNAL(clicked()),
				this, SLOT(newPubl()), true, i18n("New Publication") );
  toolbar->insertButton(BarIcon("inspubl.png"), ID_AUTHOR_INSPUBL, SIGNAL(clicked()),
				this, SLOT(insPubl()), true, i18n("Insert Publication") );
  toolbar->insertButton(BarIcon("delpubl.png"), ID_AUTHOR_REMPUBL, SIGNAL(clicked()),
				this, SLOT(remPubl()), true, i18n("Remove Publication") );
  toolbar->insertLineSeparator();
  toolbar->insertButton(BarIcon("inspart.png"), ID_AUTHOR_INSPART, SIGNAL(clicked()),
				this, SLOT(insPart()), true, i18n("Insert Part") );
  toolbar->insertButton(BarIcon("delpart.png"), ID_AUTHOR_REMPART, SIGNAL(clicked()),
				this, SLOT(remPart()), true, i18n("Remove Part") );
  toolbar->insertLineSeparator();
  toolbar->insertButton(BarIcon("filedel.png"), ID_AUTHOR_DELREC, SIGNAL(clicked()),
				this, SLOT(del()), true, i18n("Delete Record") );
  toolbar->insertLineSeparator();
  toolbar->insertButton(BarIcon("filefloppy.png"), ID_AUTHOR_FLUSH, SIGNAL(clicked()),
				this, SLOT(flush()), true, i18n("Save Changes") );
  toolbar->insertButton(BarIcon("reload.png"), ID_AUTHOR_RESET, SIGNAL(clicked()),
				this, SLOT(reread()), true, i18n("Revert Record") );
	toolbar->setBarPos(KToolBar::Top);
	toolbar->enable(KToolBar::Show);
  return toolbar;
}

==> kaspaliste-0.92.tar.bz2: kaspaliste-0.92/kaspaliste/kliste/author.cpp <==
/***************************************************************************
                          author.cpp  -  description
                             -------------------
    begin                : Tue Sep 7 1999
    copyright            : (C) 1999 by Jan Mueller
    email                : janmueller7@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "author.h"
#include "kaspawidget.h"
#include "resource.h"
#include <kapp.h>
#include <qstring.h>
#include <qmessagebox.h>
#include <kiconloader.h>
#include <klocale.h>
#include "notetreedlg.h"
#include "selectiondlg.h"
#include <qwhatsthis.h>
#include <qwidget.h>
#include <kapp.h>
#include <ktoolbar.h>
#include <kmdcodec.h>


#define Inherited AuthorData


CommandSetup authorcs[] = {	{ID_AUTHOR_DELREC,  RW},
														{ID_AUTHOR_NEWLINK, RW+RO},
														{ID_AUTHOR_INSLINK, RW+RO},
														{ID_AUTHOR_REMLINK, RW+RO},
														{ID_AUTHOR_NEWPUBL, RW+RO},
														{ID_AUTHOR_INSPUBL, RW+RO},
														{ID_AUTHOR_REMPUBL, RW+RO},
														{ID_AUTHOR_FLUSH, 	RW},
														{ID_AUTHOR_INSPART, RW+RO},
														{ID_AUTHOR_REMPART, RW+RO},
														{ID_AUTHOR_RESET,		RW+RO+INV} };



// AuthorBase-Constructor reads row matching WHERE-Clause.
Author::Author(KaspaURL url, Sql *conn, QWidget* parent,	const char* name=0L):
  Inherited( parent, name) {
    setTabOrder(firstname, lastname);
		setTabOrder(lastname, pseudonym);
		setTabOrder(pseudonym, born);
		setTabOrder(born, died);
		setTabOrder(died, country);
		setTabOrder(country, memo);

	QWhatsThis::add(firstname,	i18n("The first name of an author."));
	QWhatsThis::add(lastname, 	i18n("The name of an author."));	
	QWhatsThis::add(pseudonym,	i18n("Your author might have a pseudonym."));		
	QWhatsThis::add(born,				i18n("Once upon a time your author might have been born..."));		
	QWhatsThis::add(died,				i18n("The date of the death of an author."));		
	QWhatsThis::add(country,		i18n("The country where your author is from."));		
	QWhatsThis::add(memo , 			i18n("This textarea takes your annotations about the author."));
	QWhatsThis::add(notelist,		i18n("This box shows the links to the notes connected to an author. " \
																	 "You may open the link by double-clicking the item in the same window " \
																	 "or via the context menu in an new window. You can open the context menu" \
																	 "by clicking the right mouse button. You may insert, create and delete " \
																	 "notes with the buttons of the toolbar."));
	QWhatsThis::add(partlist,		i18n("Your author might have written some articles in a collection or a journal. " \
																	 "This box shows these parts." \
																	 "You may open a part in the same by double-clicking the item " \
																	 "or in a new window via the context menu. You can open the context menu " \
																	 "by clicking the right mouse button. You may insert and delete " \
																	 "parts with the buttons of the toolbar."));
	QWhatsThis::add(publlist,		i18n("This box shows the publications written by an author. " \
																	 "You may open a publication in the same window by double-clicking the item " \
																	 "or in a new window via the context menu. You can open the context menu " \
																	 "by clicking the right mouse button. You may insert, create and delete " \
																	 "publications with the buttons of the toolbar."));
		
	if(url.command()=="new")
	  author = new AuthorBase(conn);
	else
 		author = new AuthorBase(url.where(), conn);

  ASSERT(author);
	author->setCallBack(&idle);
	QString s("kaspa://author#where author.no="); s+=QString().setNum(author->id());
	_url=s;

  connect(notelist, SIGNAL(open(Oid, bool)), this, SLOT(requestNote(Oid, bool)));
  connect(publlist, SIGNAL(open(Oid, bool)), this, SLOT(requestPublication(Oid, bool)));
  connect(partlist, SIGNAL(open(Oid, bool)), this, SLOT(requestPart(Oid, bool)));
	notelist->setTitle(i18n("Links"));
	publlist->setTitle(i18n("Publications"));
	partlist->setTitle(i18n("Chapters"));
}

Author::~Author() {
//  debug("Author::~Author");
  delete author;
}

bool Author::isValid() {
	try {
	  return author->isValid();
	} catch(KaspaErr &err) {
		handleWarning(err);
		return false;
	}
}

void Author::reread() {
//  debug("Author::reread()");
  setWorkingGUI();
	try {
	  author->reset();
	} catch(KaspaErr &err) {
		handleWarning(err);
	}
  setFields();
}

void Author::setFields() {
  if(isValid()) {
		try {
			setWorkingGUI();
      emit setCaption(QString(author->getFirstName())+" "+QString(author->getLastName()));
  		firstname->setText(author->getFirstName());
	  	lastname->setText(author->getLastName());
	  	born->setText(author->getBirthday());
		  died->setText(author->getDay_of_Death());
  		pseudonym->setText(author->getPseudonym());
		  country->setText(author->getCountry());
  		memo->setText(QCString(author->getMemo()));
			created->setText(QString("created: ")+author->getCreated());
			modified->setText(QString("modified: ")+author->getModified());

		  notelist->set(author->getLinks());
		  publlist->set(author->getPubl());
		  partlist->set(author->getParts());
		} catch(KaspaErr &err) {
			handleWarning(err);
		}
	}
  setupGUI();
}

void Author::flush() {
	setWorkingGUI();
	save();
	setupGUI();
}

void Author::save(bool block) {
//  debug("Author::save()");
	try {
	  if(isValid() && !isReadOnly() && !isWorking()) {
	    if(strcmp(firstname->text(), author->getFirstName()))
	      author->setFirstName(firstname->text());
	    if(strcmp(lastname->text(), author->getLastName()))
	      author->setLastName(lastname->text());
	    if(strcmp(born->text(), author->getBirthday()))
	      author->setBirthday(born->text());
	    if(strcmp(died->text(), author->getDay_of_Death()))
	      author->setDay_of_Death(died->text());
	    if(strcmp(pseudonym->text(), author->getPseudonym()))
	      author->setPseudonym(pseudonym->text());
	    if(strcmp(country->text(), author->getCountry()))
	      author->setCountry(country->text());
	    if(strcmp(QCString(memo->text()), author->getMemo()))
	      author->setMemo(QCString(memo->text()));
		    author->flush(block);
		}
	} catch(KaspaErr &err) {
		handleWarning(err);
	}
}

void Author::setInvalidGUI() {
//  debug("Author::setInvalidGUI()");
  Inherited::setInvalidGUI();
  lockGUI();
	for(unsigned int i=0; i<sizeof(authorcs)/sizeof(CommandSetup); i++)
		emit enableCommand(authorcs[i].command, ((authorcs[i].setup&INV)==INV));
}	

void Author::setReadWriteGUI() {
//  debug("Author::setReadWriteGUI()");
  Inherited::setReadWriteGUI();
  unlockGUI();
	for(unsigned int i=0; i<sizeof(authorcs)/sizeof(CommandSetup); i++)
		emit enableCommand(authorcs[i].command, ((authorcs[i].setup&RW)==RW));
}

void Author::setReadOnlyGUI() {
//  debug("Author::setReadOnlyGUI()");	
  Inherited::setReadOnlyGUI();
  lockGUI();
  notelist->setEnabled(true);
  publlist->setEnabled(true);
	partlist->setEnabled(true);
	for(unsigned int i=0; i<sizeof(authorcs)/sizeof(CommandSetup); i++)
		emit enableCommand(authorcs[i].command, ((authorcs[i].setup&RO)==RO));
}

void Author::setWorkingGUI() {
//  debug("Author::setWorkingGUI()");
	if(isReadOnly() || !isValid())
		lockGUI();
	else
		unlockGUI();
  Inherited::setWorkingGUI();
  notelist->setEnabled(false);
  publlist->setEnabled(false);
	partlist->setEnabled(false);
	for(unsigned int i=0; i<sizeof(authorcs)/sizeof(CommandSetup); i++)
		emit enableCommand(authorcs[i].command, ((authorcs[i].setup&WORK)==WORK));
}


void Author::del() {
	try  {
	  if(isValid() && !isReadOnly() && !isWorking() && deleteDlg()) {
	    setWorkingGUI();
	    author->deleteRec();
	    setInvalidGUI();
		}
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}

bool Author::closeRequest() {
  save(true);
	setupGUI();
  return true;
}


void Author::newLink() {
	try {
		Oid o=author->createNote();
		requestNote(o);
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}

void Author::insLink() {
	try {
		NoteTitle *notes=author->getNotes();
		PublTitle *publs=author->getPubls();
		NoteTreeDlg dlg(notes, publs);
		if(dlg.exec()) {
			if(dlg.getOid()==InvalidOid) return;
			setWorkingGUI();
			author->insertLink(dlg.getOid());
			save();
			setFields();	
		}
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}

/*
	try {
		SelectionDlg dlg(author->getNotes(), this);
		if(dlg.exec()) {
			Oid o=dlg.getOid();
			if(o==InvalidOid) return;
			setWorkingGUI();
			author->insertLink(o);
			save();
			setFields();
		}
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}
*/

void Author::remLink() {
	try {
		Oid o=notelist->getCurrentOid();
		if(o==InvalidOid) return;
		setWorkingGUI();
		author->removeLink(o);
		save();
		setFields();
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}
		
void Author::newPubl() {
	try {
		Oid o=author->createPubl();
		requestPublication(o);
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}
	
void Author::insPubl() {
	try {
		SelectionDlg dlg(author->getPubls(), this);
		if(dlg.exec()) {
			Oid o=dlg.getOid();
			if(o==InvalidOid) return;
			setWorkingGUI();
			author->insertPubl(o);
			save();
			setFields();			
		}
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}		
	
void Author::remPubl() {
	try {
		Oid o=publlist->getCurrentOid();
		if(o==InvalidOid) return;
		setWorkingGUI();
		author->removePubl(o);
		save();
		setFields();	
		} catch(KaspaErr& err) {
			handleWarning(err);
		}
}
		
void Author::insPart() {
	try {
		SelectionDlg dlg(author->getParts(), this);
		if(dlg.exec()) {
			Oid o=dlg.getOid();
			if(o==InvalidOid) return;
			setWorkingGUI();
			author->insertPart(o);
			save();
			setFields();	
		}
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}		
	
void Author::remPart() {
	try {
	Oid o=partlist->getCurrentOid();
	if(o==InvalidOid) return;
		setWorkingGUI();
		author->removePart(o);
		save();
		setFields();	
	} catch(KaspaErr& err) {
		handleWarning(err);
	}
}

KToolBar *Author::getToolBar() {
	KaspaToolBar *toolbar = new KaspaToolBar(topLevelWidget());
  toolbar->insertButton(BarIcon("newnote.png"), ID_AUTHOR_NEWLINK, SIGNAL(clicked()),
				this, SLOT(newLink()), true, i18n("New Note") );
  toolbar->insertButton(BarIcon("insnote.png"), ID_AUTHOR_INSLINK, SIGNAL(clicked()),
				this, SLOT(insLink()), true, i18n("Insert Note") );
  toolbar->insertButton(BarIcon("delnote.png"), ID_AUTHOR_REMLINK, SIGNAL(clicked()),
				this, SLOT(remLink()), true, i18n("Delete Note") );
	toolbar->insertLineSeparator();
  toolbar->insertButton(BarIcon("newpubl.png"), ID_AUTHOR_NEWPUBL, SIGNAL(clicked()),
				this, SLOT(newPubl()), true, i18n("New Publication") );
  toolbar->insertButton(BarIcon("inspubl.png"), ID_AUTHOR_INSPUBL, SIGNAL(clicked()),
				this, SLOT(insPubl()), true, i18n("Insert Publication") );
  toolbar->insertButton(BarIcon("delpubl.png"), ID_AUTHOR_REMPUBL, SIGNAL(clicked()),
				this, SLOT(remPubl()), true, i18n("Remove Publication") );
  toolbar->insertLineSeparator();
  toolbar->insertButton(BarIcon("inspart.png"), ID_AUTHOR_INSPART, SIGNAL(clicked()),
				this, SLOT(insPart()), true, i18n("Insert Part") );
  toolbar->insertButton(BarIcon("delpart.png"), ID_AUTHOR_REMPART, SIGNAL(clicked()),
				this, SLOT(remPart()), true, i18n("Remove Part") );
  toolbar->insertLineSeparator();
  toolbar->insertButton(BarIcon("filedel.png"), ID_AUTHOR_DELREC, SIGNAL(clicked()),
				this, SLOT(del()), true, i18n("Delete Record") );
  toolbar->insertLineSeparator();
  toolbar->insertButton(BarIcon("filefloppy.png"), ID_AUTHOR_FLUSH, SIGNAL(clicked()),
				this, SLOT(flush()), true, i18n("Save Changes") );
  toolbar->insertButton(BarIcon("reload.png"), ID_AUTHOR_RESET, SIGNAL(clicked()),
				this, SLOT(reread()), true, i18n("Revert Record") );
	toolbar->setBarPos(KToolBar::Top);
	toolbar->enable(KToolBar::Show);
  return toolbar;
}
